aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/fo/FOEventHandler.java
diff options
context:
space:
mode:
authorAdrian Cumiskey <acumiskey@apache.org>2008-06-21 16:10:03 +0000
committerAdrian Cumiskey <acumiskey@apache.org>2008-06-21 16:10:03 +0000
commit30d0f7a3e83bf0e2d7866ea623f64d6f8204a13e (patch)
tree092254d9437bd86b20ae305ace405fc7712b557e /src/java/org/apache/fop/fo/FOEventHandler.java
parent4ae76120cfae1310834b6a7a4e50fac833eb81d8 (diff)
downloadxmlgraphics-fop-30d0f7a3e83bf0e2d7866ea623f64d6f8204a13e.tar.gz
xmlgraphics-fop-30d0f7a3e83bf0e2d7866ea623f64d6f8204a13e.zip
Moved the contents of TableBody into a new abstract base class TablePart, which is now subclassed by TableBody, TableHeader and TableFooter.
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@670217 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org/apache/fop/fo/FOEventHandler.java')
-rw-r--r--src/java/org/apache/fop/fo/FOEventHandler.java27
1 files changed, 15 insertions, 12 deletions
diff --git a/src/java/org/apache/fop/fo/FOEventHandler.java b/src/java/org/apache/fop/fo/FOEventHandler.java
index 880dd7868..90856d57a 100644
--- a/src/java/org/apache/fop/fo/FOEventHandler.java
+++ b/src/java/org/apache/fop/fo/FOEventHandler.java
@@ -40,6 +40,9 @@ import org.apache.fop.fo.flow.PageNumberCitation;
import org.apache.fop.fo.flow.PageNumberCitationLast;
import org.apache.fop.fo.flow.table.Table;
import org.apache.fop.fo.flow.table.TableBody;
+import org.apache.fop.fo.flow.table.TableFooter;
+import org.apache.fop.fo.flow.table.TableHeader;
+import org.apache.fop.fo.flow.table.TablePart;
import org.apache.fop.fo.flow.table.TableCell;
import org.apache.fop.fo.flow.table.TableColumn;
import org.apache.fop.fo.flow.table.TableRow;
@@ -257,44 +260,44 @@ public abstract class FOEventHandler {
/**
*
- * @param th TableBody that is starting;
+ * @param header TableHeader that is starting;
*/
- public void startHeader(TableBody th) {
+ public void startHeader(TableHeader header) {
}
/**
*
* @param th TableBody that is ending.
*/
- public void endHeader(TableBody th) {
+ public void endHeader(TableHeader header) {
}
/**
*
- * @param tf TableFooter that is starting.
+ * @param footer TableFooter that is starting.
*/
- public void startFooter(TableBody tf) {
+ public void startFooter(TableFooter footer) {
}
/**
*
- * @param tf TableFooter that is ending.
+ * @param footer TableFooter that is ending.
*/
- public void endFooter(TableBody tf) {
+ public void endFooter(TableFooter footer) {
}
/**
*
- * @param tb TableBody that is starting.
+ * @param body TableBody that is starting.
*/
- public void startBody(TableBody tb) {
+ public void startBody(TableBody body) {
}
/**
*
- * @param tb TableBody that is ending.
+ * @param body TableBody that is ending.
*/
- public void endBody(TableBody tb) {
+ public void endBody(TableBody body) {
}
/**
@@ -257,44 +260,44 @@ public abstract class FOEventHandler {
/**
*
- * @param th TableBody that is ending.
+ * @param header TableHeader that is ending.
*/